@@ -8,7 +8,7 @@ package IO::Async::SSL;
 use strict;
 use warnings;
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 $VERSION = eval $VERSION;
 
 use Carp;
@@ -117,6 +117,10 @@ sub sslwrite
    my $stream = shift;
    my ( $fh, undef, $len ) = @_;
 
+   # Placate RT98372
+   utf8::downgrade( $_[1] ) or
+      carp "Wide character in sslwrite";
+
    my $ret = $stream->_syswrite( $fh, $_[1], $len );
 
    my $write_wants_read = !defined $ret &&
